/*
 * itm.h
 *
 */

#ifndef ITM_H_
#define ITM_H_


//*****************************************************************************
//
// If building with a C++ compiler, make all of the definitions in this header
// have a C binding.
//
//*****************************************************************************
#ifdef __cplusplus
extern "C"
{
#endif

/* Standard Includes */
#include <stdint.h>
#include <stdbool.h>
#include <string.h>

typedef enum
{
    ITM_9600 = 9600,
    ITM_57600 = 57600,
    ITM_115200 = 115200,
    ITM_230400 = 230400,
    ITM_460800 = 460800,
    ITM_500000 = 500000,
    ITM_576000 = 576000,
    ITM_921600 = 921600,
    ITM_1000000 = 1000000,
    ITM_1152000 = 1152000,
    ITM_1500000 = 1500000,
    ITM_2000000 = 2000000,
    ITM_2500000 = 2500000,
    ITM_3000000 = 3000000,
    ITM_3500000 = 3500000,
    ITM_4000000 = 4000000
} ITM_baudrate;


typedef struct _ITM_config_
{
    uint_fast32_t systemClock;
    ITM_baudrate  baudRate;
} ITM_config;


//*****************************************************************************
//
//! Initialize the ITM module.
//!
//! \param itm_config provides configuration parameters.
//!
//! This function will initialize the ITM/TPIU module for UART SWO mode.
//!
//! \return None.
//
//*****************************************************************************
extern void ITM_initModule(const ITM_config itm_config);

//*****************************************************************************
//
//! Enable ITM module.
//!
//! \param None.
//!
//! This function will enable ITM module for trace generation.
//!
//! \return None.
//
//*****************************************************************************
extern void ITM_enableModule();

//*****************************************************************************
//
//! Disable ITM module.
//!
//! \param None.
//!
//! This function will disable trace generation by ITM module.
//!
//! \return None.
//
//*****************************************************************************
extern void ITM_disableModule();

//*****************************************************************************
//
//! Generate string message.
//!
//! \param msg Null terminated string to transmit.
//! \param port Stimulus port number to use for transmission.
//!
//! This function will write out the characters to the stimulus port specified.
//! This function is blocking which means the function will not return until
//! all characters are transferred.
//!
//! \return None.
//
//*****************************************************************************
extern void ITM_putStringBlocking(const char* msg, const uint8_t port);

//*****************************************************************************
//
//! Generate 32-bit word message.
//!
//! \param msg 32-bit word.
//! \param port Stimulus port number to use for transmission.
//!
//! This function will write out the 32-bit word to the stimulus port
//! specified. This function is blocking which means the function will not
//! return until all data is transferred.
//!
//! \return None.
//
//*****************************************************************************
extern void ITM_putWordBlocking(const uint32_t msg, const uint8_t port);

//*****************************************************************************
//
// Mark the end of the C bindings section for C++ compilers.
//
//*****************************************************************************
#ifdef __cplusplus
}
#endif

#endif /* ITM_H_ */
